@@ -75,7 +75,7 @@ async def button(bot, update: CallbackQuery):
                         else:
                             os.remove(file_name)
                     await i_m_s_e_g.edit_text(
-                        f"Leech cancelled by <a href='tg://user?id={update.from_user.id}'>{update.from_user.first_name}</a>"
+                        f"Leech cancelled by <a href='tg://user?id={message.from_user.id}'>{message.from_user.first_name}</a>"
                     )
                 except Exception as e:
                     await i_m_s_e_g.edit_text("<i>FAILED</i>\n\n" + str(e) + "\n#error")
